# $File: //depot/OurNet-BBS/BBS/PTT/UserGroup.pm $ $Author: autrijus $
# $Revision: #3 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $

package OurNet::BBS::PTT::UserGroup;

use base qw/OurNet::BBS::MAPLE2::UserGroup/;
use fields qw/_ego _hash _array/;
use OurNet::BBS::Base;

1;
